@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11977 2020-03-16 18:37:48Z Lavender $
+# $Id: __init__.py 12211 2020-05-13 13:11:29Z Andy $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-03-17 02:37:48 +0800 (週二, 17 三月 2020) $
-# $Revision: 11977 $
+# $Author: Andy $ (last)
+# $Date: 2020-05-13 21:11:29 +0800 (週三, 13 五月 2020) $
+# $Revision: 12211 $
 
 import os
 import sys
@@ -28,8 +28,7 @@ import logging
 
 from Iuppiter.Util import extendUnique
 from Iuppiter.DjangoUtil import (
-    extendInstalledApps, DJANGO_VERSION, extendMiddlewareClasses)
-
+    extendInstalledApps, DJANGO_VERSION, extendMiddlewareClasses, patterns)
 from .Version import ZEPHYRUS_VERSION
 
 def createLogger(name, fileHandlerName):
@@ -105,6 +104,7 @@ def attachSettings(settingsDict):
         'django_gravatar',
         'captcha',
         'Zephyrus.map',
+        
     ]
     
     if ZEPHYRUS_BLOG_ENABLE:
@@ -122,6 +122,7 @@ def attachSettings(settingsDict):
             
             'django.contrib.redirects',
             'Zephyrus.blog_extension',
+            'Zephyrus.seo',
         ]
 
     if ZEPHYRUS_OSCAR_ENABLE:
@@ -297,6 +298,26 @@ def attachSettings(settingsDict):
                     value['EXCLUDED_INDEXES'] = [
                         'aldryn_people.search_indexes.PeopleIndex',
                     ]
+                    
+def attachURLs(settings, urlpatterns):
+    """
+    Attach patched (for example, debug and admin...etc.) urlpatterns.
+    It must be called in urls.py by passing urlpatterns.
+
+    @param settings Django project's settings module.
+    @param urlpatterns urlpatterns in urls.py.
+    """
+    from django.conf.urls import url, include
+
+    urlpatterns += patterns('',
+        url(r'^landing/', include('Zephyrus.landing.urls')),
+        url(r'^', include('Zephyrus.comment.urls')),
+        url(r'^', include('Zephyrus.facebook.urls')),
+    )
+    
+    from Zephyrus import seo
+    
+    seo.attachURLs(settings, urlpatterns)
             
 
     
