@@ -67,6 +67,7 @@ from Zephyrus.landing import ErrorCode
 from Zephyrus.landing.models import Email
 from Zephyrus.blog_extension.models import CallToActionModel, CallToActionStatistics
 from Zephyrus.blog_extension import settings as _settings
+from Zephyrus.ZephyrusSettings import BASE_DIR as ZEPHYRUS_BASE_DIR
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -308,7 +309,16 @@ class CallToActionSocialView(View):
 
 
 def showTargetFile(request):
-
+    
+    import sys
+    # local windows use PE file in Zephyrus
+    if sys.platform.startswith("win32"):
+        config = pdfkit.configuration(wkhtmltopdf=os.path.join(ZEPHYRUS_BASE_DIR, 'wkhtmltopdf.exe'))
+    
+    # on Linux, pdfkit complete configuration by which 
+    else:
+        config = None
+    
     def returnTargetFile(request, callToActionStatistics):
         if callToActionStatistics.action.targetFile:
 
@@ -342,7 +352,7 @@ def showTargetFile(request):
                 try:
                     
                     pdfkit.from_url(settings.META_SITE_PROTOCOL + '://' + domain + reverse('renderArticle', 
-                                    kwargs={'articleId': articleId}), path[1:])
+                                    kwargs={'articleId': articleId}), path[1:], configuration=config)
 
                 # might occur as the https is at risk
                 # the file(img or any file on site) is loaded successfully
@@ -372,6 +382,7 @@ def showTargetFile(request):
                 pdfkit.from_url(
                     f"{settings.META_SITE_PROTOCOL}://{domain}{callToActionStatistics.url}",
                     path[1:],
+                    configuration=config,
                 )
             # response = serve(request, path, document_root=settings.BASE_DIR)
 
