@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12107 2020-04-23 08:17:04Z Lavender $
+# $Id: __init__.py 12209 2020-05-13 07:27:11Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-23 16:17:04 +0800 (週四, 23 四月 2020) $
-# $Revision: 12107 $
+# $Date: 2020-05-13 15:27:11 +0800 (週三, 13 五月 2020) $
+# $Revision: 12209 $
 
 import json
 import requests
@@ -32,6 +32,8 @@ else:
 
 class Settings(object):
     # Facebook Nuwa Blog APP
+    ZEPHYRUS_FACEBOOK_DEFAULT_GET_ACCESS_TOKEN_URL = "https://www.nuwainfo.com"
+    ZEPHYRUS_FACEBOOK_DEFAULT_PASSWORD = "@%)@5529"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
     ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN = "25025529"
@@ -58,7 +60,8 @@ class Settings(object):
         for ele in _settings.ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES:
             if not ele[0] == "facebook/FacebookPhotoPlugin.html":
                 ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES.append(ele)
-                
+   
+SCOPE = ["manage_pages", "pages_show_list"]  
 MANAGE_PAGES_STATE = "manage_pages"
     
 settings = Settings()
